==> phantomjs-maven-plugin-0.2-sources.jar: com/github/klieber/phantomjs/archive/LinuxPhantomJSArchive.java <==
/*
 * Copyright (c) 2013 Kyle Lieber
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 * the Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package com.github.klieber.phantomjs.archive;

public class LinuxPhantomJSArchive extends PhantomJSArchive {

	private final String arch;

	public LinuxPhantomJSArchive(String version, String arch) {
		super(version);
		this.arch = arch;
	}

	@Override
	protected String getExtension() {
		return "tar.bz2";
	}

	@Override
	protected String getPlatform() {
		return "linux";
	}

	@Override
	protected String getExecutable() {
		return "bin/phantomjs";
	}
	
	@Override
	protected String getArch() {
		return this.arch;
	}
}

==> phantomjs-maven-plugin-0.5-sources.jar: com/github/klieber/phantomjs/archive/LinuxPhantomJSArchive.java <==
/*
 * Copyright (c) 2013 Kyle Lieber
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 * the Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package com.github.klieber.phantomjs.archive;

public class LinuxPhantomJSArchive extends PhantomJSArchive {

	private final String arch;

	public LinuxPhantomJSArchive(String version, String arch) {
		super(version);
		this.arch = arch;
	}

	@Override
	public String getExtension() {
		return "tar.bz2";
	}

	@Override
	protected String getPlatform() {
		return "linux";
	}

	@Override
	protected String getExecutable() {
		return "bin/phantomjs";
	}
	
	@Override
	protected String getArch() {
		return this.arch;
	}
}
